Name:           ompl
Version:        1.0.0
Release:        2%{?dist}
Summary:        The Open Motion Planning Library

Group:          System Environment/Libraries
License:        BSD
URL:            http://ompl.kavrakilab.org/
Source0:        https://bitbucket.org/%{name}/%{name}/downloads/%{name}-%{version}-Source.tar.gz
BuildRequires:  boost-devel >= 1.42.0
BuildRequires:  cmake >= 2.8.2
BuildRequires:  doxygen
BuildRequires:  flann-devel
BuildRequires:  graphviz
BuildRequires:  ode-devel
BuildRequires:  python
BuildRequires:  ruby

%description
The Open Motion Planning Library (OMPL) consists of many state-of-the-art 
sampling-based motion planning algorithms. OMPL itself does not contain 
any code related to, e.g., collision checking or visualization. This is 
a deliberate design choice, so that OMPL is not tied to a particular 
collision checker or visualization front end.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       boost-devel

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%setup -q -n %{name}-%{version}-Source
# Get rid of bundled odeint
rm -rf src/external/omplext_odeint/

%build
# Python bindings are disabled because dependencies pygccxml and pyplusplus are not packaged for Fedora
mkdir build
cd build
%cmake -DCMAKE_SKIP_RPATH=ON \
  -DOMPL_BUILD_PYBINDINGS=OFF \
  -DOMPL_LIB_INSTALL_DIR=%{_lib} \
  -DBOOST_LIBRARYDIR=%{_libdir} \
  -DODE_LIB_PATH=%{_libdir} \
  -DBUILD_OMPL_TESTS=ON  \
  -DOMPL_ODESOLVER=ON \
  -DOMPL_REGISTRATION=OFF ..

make %{?_smp_mflags}
make doc
rm -f doc/html/installdox

%install
make -C build install DESTDIR=%{buildroot}
mkdir -p %{buildroot}%{_datadir}/cmake/Modules
cp %{buildroot}%{_datadir}/ompl/ompl-config.cmake %{buildroot}%{_datadir}/cmake/Modules/FindOMPL.cmake

rm -f %{buildroot}%{_datadir}/%{name}/demos/*.py
rm -rf %{buildroot}%{_includedir}/%{name}/CMakeFiles
rm -rf %{buildroot}%{_bindir}

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
make -C build test || exit 0

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%defattr(-,root,root,-)
%doc LICENSE README.md
%{_libdir}/libompl.so.*
%{_mandir}/man1/*.1.*

%files devel
%defattr(-,root,root,-)
%doc doc/html
%{_libdir}/libompl.so
%{_includedir}/%{name}
%{_datadir}/%{name}
%{_libdir}/pkgconfig/*.pc
%{_datadir}/cmake/Modules/FindOMPL.cmake

%changelog
* Mon Jan 26 2015 Petr Machata <pmachata@redhat.com> - 1.0.0-2
- Rebuild for boost 1.57.0

* Fri Oct 31 2014 Rich Mattes <richmattes@gmail.com> - 1.0.0-1
- Update to release 1.0.0

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.14.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.14.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 30 2014 Rich Mattes <rmattes@fedoraproject.org> - 0.14.2-1
- Update to release 0.14.2

* Thu May 22 2014 Petr Machata <pmachata@redhat.com> - 0.13.0-2
- Rebuild for boost 1.55.0

* Wed Aug 21 2013 Rich Mattes <richmattes@gmail.com> - 0.13.0-1
- Update to release 0.13.0

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.12.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jul 27 2013 pmachata@redhat.com - 0.12.2-2
- Rebuild for boost 1.54.0

* Wed May 01 2013 Rich Mattes <richmattes@gmail.com> - 0.12.2-1
- Update to release 0.12.2
- Remove bundled odeint

* Sun Feb 10 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.11.1-4
- Rebuild for Boost-1.53.0

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.11.1-3
- Rebuild for Boost-1.53.0

* Mon Aug 20 2012 Jon Ciesla <limburgher@gmail.com> - 0.11.1-2
- Rebuild for new ode.

* Thu Aug 09 2012 Rich Mattes <richmattes@gmail.com> - 0.11.1-1
- Update to release 0.11.1

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue May 15 2012 Rich Mattes <richmattes@gmail.com> - 0.10.2-1
- Update to release 0.10.2

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.5-4
- Rebuilt for c++ ABI breakage

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Nov 20 2011 Rich Mattes <richmattes@gmail.com> - 0.9.5-2
- Rebuilt for new boost

* Sun Oct 9 2011 Rich Mattes <richmattes@gmail.com> - 0.9.5-1
- Update to release 0.9.5

* Thu Jul 21 2011 Rich Mattes <richmattes@gmail.com> - 0.9.3-2
- Add python build requirement

* Sun May 15 2011 Rich Mattes <richmattes@gmail.com> - 0.9.3-1
- Update to 0.9.3
- Remove upstreamed patches

* Sun Apr 24 2011 Rich Mattes <richmattes@gmail.com> - 0.9.2-2
- Add patch to fix missing soname
- Removed CMakeFiles being installed in the includedir
- Fixed download directory

* Sun Jan 23 2011 Rich Mattes <richmattes@gmail.com> - 0.9.2-1
- Initial Package
